Learn R Programming

epxToR (version 0.4-1)

read.epx: Import an Epidata xml file (.epx)

Description

Import an Epidata xml file (.epx)

Usage

read.epx(x, use.epidata.labels = TRUE, set.missing.na = TRUE)

Arguments

x

char - Filename

use.epidata.labels

Boolean - replace value of a variable by an internal label. Default is TRUE

set.missing.na

Boolean - replace missing by NA. Default is TRUE

Value

An "epx" object

Details

This function read an Epidata file containing new xml format data.

References

----

Examples

Run this code
# NOT RUN {
# -----------
# }

Run the code above in your browser using DataLab