powered by
Import an Epidata xml file (.epx)
read.epx(x, use.epidata.labels = TRUE, set.missing.na = TRUE)
char - Filename
Boolean - replace value of a variable by an internal label. Default is TRUE
Boolean - replace missing by NA. Default is TRUE
An "epx" object
This function read an Epidata file containing new xml format data.
----
# NOT RUN { # ----------- # }
Run the code above in your browser using DataLab